@@ -10,6 +10,7 @@ $VERSION = 0.01;
 %yagg::Config = (
   'programs' => {
     'ar' => '/usr/bin/ar',
+    'c++' => '/usr/bin/c++',
     'chmod' => '/usr/local/opt/coreutils/libexec/gnubin/chmod',
     'cp' => '/usr/local/opt/coreutils/libexec/gnubin/cp',
     'cpp' => '/usr/bin/cpp',
@@ -17,7 +18,6 @@ $VERSION = 0.01;
     'dirname' => '/usr/local/opt/coreutils/libexec/gnubin/dirname',
     'expr' => '/usr/local/opt/coreutils/libexec/gnubin/expr',
     'find' => '/usr/bin/find',
-    'g++' => '/usr/local/bin/g++-4.9',
     'grep' => '/usr/bin/grep',
     'ln' => '/usr/local/opt/coreutils/libexec/gnubin/ln',
     'make' => '/usr/bin/make',
