@@ -54,486 +54,486 @@ sub new {
 	{#State 0
 		DEFAULT => -3,
 		GOTOS => {
-			'declarations' => 1,
-			'input' => 2
+			'input' => 1,
+			'declarations' => 2
 		}
 	},
 	{#State 1
 		ACTIONS => {
-			'PERCENT_VERBOSE' => 7,
-			'PROLOGUE' => 5,
-			'PERCENT_TOKEN' => 6,
-			'PERCENT_DEBUG' => 4,
-			'PERCENT_EXPECT' => 3,
-			'PERCENT_NONASSOC' => 15,
-			'SEMICOLON' => 12,
-			'PERCENT_YACC' => 10,
-			"%%" => 11,
-			'PERCENT_FILE_PREFIX' => 9,
-			'PERCENT_RIGHT' => 8,
-			'PERCENT_TYPE' => 20,
-			'PERCENT_TOKEN_TABLE' => 19,
-			'PERCENT_UNION' => 18,
-			'PERCENT_DEFINES' => 27,
-			'PERCENT_NAME_PREFIX' => 30,
-			'PERCENT_START' => 28,
-			'PERCENT_PURE_PARSER' => 26,
-			'PERCENT_NO_LINES' => 25,
-			'PERCENT_LOCATIONS' => 24,
-			'PERCENT_OUTPUT' => 23,
-			'PERCENT_PARSE_PARAM' => 21,
-			'PERCENT_LEFT' => 22
-		},
-		GOTOS => {
-			'precedence_declarator' => 16,
-			'symbol_declaration' => 17,
-			'precedence_declaration' => 13,
-			'grammar_declaration' => 29,
-			'declaration' => 14
+			'' => 3
 		}
 	},
 	{#State 2
 		ACTIONS => {
-			'' => 31
+			'PERCENT_YACC' => 29,
+			'PERCENT_PURE_PARSER' => 28,
+			'PERCENT_OUTPUT' => 31,
+			'PERCENT_START' => 30,
+			'PERCENT_TOKEN_TABLE' => 21,
+			'PERCENT_NAME_PREFIX' => 20,
+			'PERCENT_NO_LINES' => 19,
+			"%%" => 27,
+			'PERCENT_TOKEN' => 24,
+			'PROLOGUE' => 25,
+			'PERCENT_DEBUG' => 23,
+			'PERCENT_FILE_PREFIX' => 22,
+			'PERCENT_NONASSOC' => 13,
+			'PERCENT_LEFT' => 12,
+			'PERCENT_EXPECT' => 16,
+			'PERCENT_VERBOSE' => 15,
+			'PERCENT_RIGHT' => 14,
+			'SEMICOLON' => 5,
+			'PERCENT_DEFINES' => 4,
+			'PERCENT_TYPE' => 6,
+			'PERCENT_PARSE_PARAM' => 7,
+			'PERCENT_UNION' => 8,
+			'PERCENT_LOCATIONS' => 10
+		},
+		GOTOS => {
+			'declaration' => 17,
+			'symbol_declaration' => 18,
+			'precedence_declaration' => 9,
+			'grammar_declaration' => 11,
+			'precedence_declarator' => 26
 		}
 	},
 	{#State 3
-		ACTIONS => {
-			'INT' => 32
-		}
+		DEFAULT => 0
 	},
 	{#State 4
-		DEFAULT => -7
+		DEFAULT => -8
 	},
 	{#State 5
-		DEFAULT => -6
+		DEFAULT => -20
 	},
 	{#State 6
 		ACTIONS => {
-			'IDENT' => 37,
-			'TYPE' => 36
-		},
-		GOTOS => {
-			'ID' => 35,
-			'symbol_defs_1' => 34,
-			'symbol_def' => 33
+			'TYPE' => 32
 		}
 	},
 	{#State 7
-		DEFAULT => -18
+		DEFAULT => -15
 	},
 	{#State 8
-		DEFAULT => -30
+		ACTIONS => {
+			'BRACED_CODE' => 33
+		}
 	},
 	{#State 9
-		ACTIONS => {
-			'EQUAL' => 38
-		}
-	},
-	{#State 10
-		DEFAULT => -19
-	},
-	{#State 11
-		ACTIONS => {
-			'ID_COLON' => 41,
-			'ERROR' => 43,
-			'SEMICOLON' => 42
-		},
-		DEFAULT => -2,
-		GOTOS => {
-			'rules_or_grammar_declaration' => 40,
-			'rules' => 39,
-			'grammar' => 44
-		}
-	},
-	{#State 12
-		DEFAULT => -20
-	},
-	{#State 13
 		DEFAULT => -21
 	},
+	{#State 10
+		DEFAULT => -11
+	},
+	{#State 11
+		DEFAULT => -5
+	},
+	{#State 12
+		DEFAULT => -29
+	},
+	{#State 13
+		DEFAULT => -31
+	},
 	{#State 14
-		DEFAULT => -4
+		DEFAULT => -30
 	},
 	{#State 15
-		DEFAULT => -31
+		DEFAULT => -18
 	},
 	{#State 16
 		ACTIONS => {
-			'TYPE' => 46
-		},
-		DEFAULT => -32,
-		GOTOS => {
-			'type_opt' => 45
+			'INT' => 34
 		}
 	},
 	{#State 17
-		DEFAULT => -22
+		DEFAULT => -4
 	},
 	{#State 18
-		ACTIONS => {
-			'BRACED_CODE' => 47
-		}
+		DEFAULT => -22
 	},
 	{#State 19
-		DEFAULT => -17
+		DEFAULT => -13
 	},
 	{#State 20
 		ACTIONS => {
-			'TYPE' => 48
+			'EQUAL' => 35
 		}
 	},
 	{#State 21
-		DEFAULT => -15
+		DEFAULT => -17
 	},
 	{#State 22
-		DEFAULT => -29
-	},
-	{#State 23
-		DEFAULT => -14
-	},
-	{#State 24
-		DEFAULT => -11
-	},
-	{#State 25
-		DEFAULT => -13
-	},
-	{#State 26
-		DEFAULT => -16
-	},
-	{#State 27
-		DEFAULT => -8
-	},
-	{#State 28
 		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
-		},
-		GOTOS => {
-			'ID' => 52,
-			'symbol' => 49,
-			'string_as_id' => 50
+			'EQUAL' => 36
 		}
 	},
+	{#State 23
+		DEFAULT => -7
+	},
+	{#State 24
+		ACTIONS => {
+			'IDENT' => 39,
+			'TYPE' => 38
+		},
+		GOTOS => {
+			'symbol_def' => 37,
+			'ID' => 40,
+			'symbol_defs_1' => 41
+		}
+	},
+	{#State 25
+		DEFAULT => -6
+	},
+	{#State 26
+		ACTIONS => {
+			'TYPE' => 42
+		},
+		DEFAULT => -32,
+		GOTOS => {
+			'type_opt' => 43
+		}
+	},
+	{#State 27
+		ACTIONS => {
+			'ID_COLON' => 48,
+			'ERROR' => 47,
+			'SEMICOLON' => 46
+		},
+		DEFAULT => -2,
+		GOTOS => {
+			'rules_or_grammar_declaration' => 45,
+			'rules' => 44,
+			'grammar' => 49
+		}
+	},
+	{#State 28
+		DEFAULT => -16
+	},
 	{#State 29
-		DEFAULT => -5
+		DEFAULT => -19
 	},
 	{#State 30
 		ACTIONS => {
-			'EQUAL' => 53
+			'STRING' => 50,
+			'IDENT' => 39
+		},
+		GOTOS => {
+			'ID' => 52,
+			'string_as_id' => 53,
+			'symbol' => 51
 		}
 	},
 	{#State 31
-		DEFAULT => 0
+		DEFAULT => -14
 	},
 	{#State 32
-		DEFAULT => -9
+		ACTIONS => {
+			'STRING' => 50,
+			'IDENT' => 39
+		},
+		GOTOS => {
+			'symbol' => 54,
+			'symbols_1' => 55,
+			'ID' => 52,
+			'string_as_id' => 53
+		}
 	},
 	{#State 33
-		DEFAULT => -40
+		DEFAULT => -24
 	},
 	{#State 34
-		ACTIONS => {
-			'IDENT' => 37
-		},
-		DEFAULT => -25,
-		GOTOS => {
-			'ID' => 35,
-			'symbol_def' => 54
-		}
+		DEFAULT => -9
 	},
 	{#State 35
 		ACTIONS => {
-			'INT' => 55,
-			'STRING' => 51
+			'STRING' => 57
 		},
-		DEFAULT => -36,
 		GOTOS => {
-			'string_as_id' => 56
+			'string_content' => 56
 		}
 	},
 	{#State 36
 		ACTIONS => {
-			'IDENT' => 37
-		},
-		GOTOS => {
-			'symbol_def' => 33,
-			'symbol_defs_1' => 57,
-			'ID' => 35
-		}
-	},
-	{#State 37
-		DEFAULT => -64
-	},
-	{#State 38
-		ACTIONS => {
-			'STRING' => 59
+			'STRING' => 57
 		},
 		GOTOS => {
 			'string_content' => 58
 		}
 	},
+	{#State 37
+		DEFAULT => -40
+	},
+	{#State 38
+		ACTIONS => {
+			'IDENT' => 39
+		},
+		GOTOS => {
+			'ID' => 40,
+			'symbol_def' => 37,
+			'symbol_defs_1' => 59
+		}
+	},
 	{#State 39
-		DEFAULT => -44
+		DEFAULT => -64
 	},
 	{#State 40
-		DEFAULT => -42
+		ACTIONS => {
+			'INT' => 60,
+			'STRING' => 50
+		},
+		DEFAULT => -36,
+		GOTOS => {
+			'string_as_id' => 61
+		}
 	},
 	{#State 41
-		DEFAULT => -51,
+		ACTIONS => {
+			'IDENT' => 39
+		},
+		DEFAULT => -25,
 		GOTOS => {
-			'rhses_1' => 60,
-			'rhs' => 61
+			'symbol_def' => 62,
+			'ID' => 40
 		}
 	},
 	{#State 42
-		DEFAULT => -47
+		DEFAULT => -33
 	},
 	{#State 43
 		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51,
-			'SEMICOLON' => 62
+			'IDENT' => 39,
+			'STRING' => 50
 		},
 		GOTOS => {
-			'string_as_id' => 50,
-			'symbol' => 63,
-			'ID' => 52
+			'string_as_id' => 53,
+			'ID' => 52,
+			'symbols_1' => 63,
+			'symbol' => 54
 		}
 	},
 	{#State 44
-		ACTIONS => {
-			'ERROR' => 43,
-			"%%" => 64,
-			'SEMICOLON' => 42,
-			'ID_COLON' => 41
-		},
-		DEFAULT => -62,
-		GOTOS => {
-			'epilogue_opt' => 66,
-			'rules' => 39,
-			'rules_or_grammar_declaration' => 65
-		}
+		DEFAULT => -44
 	},
 	{#State 45
-		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
-		},
-		GOTOS => {
-			'symbol' => 67,
-			'symbols_1' => 68,
-			'string_as_id' => 50,
-			'ID' => 52
-		}
+		DEFAULT => -42
 	},
 	{#State 46
-		DEFAULT => -33
+		DEFAULT => -47
 	},
 	{#State 47
-		DEFAULT => -24
-	},
-	{#State 48
 		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
+			'IDENT' => 39,
+			'STRING' => 50,
+			'SEMICOLON' => 65
 		},
 		GOTOS => {
-			'symbol' => 67,
-			'symbols_1' => 69,
-			'string_as_id' => 50,
-			'ID' => 52
+			'symbol' => 64,
+			'ID' => 52,
+			'string_as_id' => 53
+		}
+	},
+	{#State 48
+		DEFAULT => -51,
+		GOTOS => {
+			'rhses_1' => 66,
+			'rhs' => 67
 		}
 	},
 	{#State 49
-		DEFAULT => -23
+		ACTIONS => {
+			'SEMICOLON' => 46,
+			"%%" => 68,
+			'ID_COLON' => 48,
+			'ERROR' => 47
+		},
+		DEFAULT => -62,
+		GOTOS => {
+			'rules' => 44,
+			'rules_or_grammar_declaration' => 70,
+			'epilogue_opt' => 69
+		}
 	},
 	{#State 50
-		DEFAULT => -56
+		DEFAULT => -60
 	},
 	{#State 51
-		DEFAULT => -60
+		DEFAULT => -23
 	},
 	{#State 52
 		DEFAULT => -55
 	},
 	{#State 53
-		ACTIONS => {
-			'STRING' => 59
-		},
-		GOTOS => {
-			'string_content' => 70
-		}
+		DEFAULT => -56
 	},
 	{#State 54
-		DEFAULT => -41
+		DEFAULT => -34
 	},
 	{#State 55
 		ACTIONS => {
-			'STRING' => 51
+			'STRING' => 50,
+			'IDENT' => 39
 		},
-		DEFAULT => -37,
+		DEFAULT => -27,
 		GOTOS => {
-			'string_as_id' => 71
+			'string_as_id' => 53,
+			'ID' => 52,
+			'symbol' => 71
 		}
 	},
 	{#State 56
-		DEFAULT => -38
+		DEFAULT => -12
 	},
 	{#State 57
-		ACTIONS => {
-			'IDENT' => 37
-		},
-		DEFAULT => -26,
-		GOTOS => {
-			'ID' => 35,
-			'symbol_def' => 54
-		}
+		DEFAULT => -61
 	},
 	{#State 58
 		DEFAULT => -10
 	},
 	{#State 59
-		DEFAULT => -61
+		ACTIONS => {
+			'IDENT' => 39
+		},
+		DEFAULT => -26,
+		GOTOS => {
+			'ID' => 40,
+			'symbol_def' => 62
+		}
 	},
 	{#State 60
 		ACTIONS => {
-			'PIPE' => 72
+			'STRING' => 50
 		},
-		DEFAULT => -48
-	},
-	{#State 61
-		ACTIONS => {
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 74,
-			'IDENT' => 37,
-			'STRING' => 51,
-			'BRACED_CODE' => -57,
-			'PERCENT_PREC' => 75
-		},
-		DEFAULT => -49,
+		DEFAULT => -37,
 		GOTOS => {
-			'symbol' => 76,
-			'string_as_id' => 50,
-			'action_opt' => 73,
-			'ID' => 52
+			'string_as_id' => 72
 		}
 	},
+	{#State 61
+		DEFAULT => -38
+	},
 	{#State 62
-		DEFAULT => -46
+		DEFAULT => -41
 	},
 	{#State 63
 		ACTIONS => {
-			'SEMICOLON' => 77
-		}
-	},
-	{#State 64
-		ACTIONS => {
-			'EPILOGUE' => 78
-		}
-	},
-	{#State 65
-		DEFAULT => -43
-	},
-	{#State 66
-		DEFAULT => -1
-	},
-	{#State 67
-		DEFAULT => -34
-	},
-	{#State 68
-		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
+			'IDENT' => 39,
+			'STRING' => 50
 		},
 		DEFAULT => -28,
 		GOTOS => {
 			'ID' => 52,
-			'string_as_id' => 50,
-			'symbol' => 79
+			'string_as_id' => 53,
+			'symbol' => 71
+		}
+	},
+	{#State 64
+		ACTIONS => {
+			'SEMICOLON' => 73
+		}
+	},
+	{#State 65
+		DEFAULT => -46
+	},
+	{#State 66
+		ACTIONS => {
+			'PIPE' => 74
+		},
+		DEFAULT => -48
+	},
+	{#State 67
+		ACTIONS => {
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 78,
+			'IDENT' => 39,
+			'BRACED_CODE' => -57,
+			'STRING' => 50,
+			'PERCENT_PREC' => 76
+		},
+		DEFAULT => -49,
+		GOTOS => {
+			'ID' => 52,
+			'action_opt' => 77,
+			'string_as_id' => 53,
+			'symbol' => 75
+		}
+	},
+	{#State 68
+		ACTIONS => {
+			'EPILOGUE' => 79
 		}
 	},
 	{#State 69
-		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
-		},
-		DEFAULT => -27,
-		GOTOS => {
-			'ID' => 52,
-			'symbol' => 79,
-			'string_as_id' => 50
-		}
+		DEFAULT => -1
 	},
 	{#State 70
-		DEFAULT => -12
+		DEFAULT => -43
 	},
 	{#State 71
-		DEFAULT => -39
+		DEFAULT => -35
 	},
 	{#State 72
+		DEFAULT => -39
+	},
+	{#State 73
+		DEFAULT => -45
+	},
+	{#State 74
 		DEFAULT => -51,
 		GOTOS => {
 			'rhs' => 80
 		}
 	},
-	{#State 73
+	{#State 75
+		DEFAULT => -52
+	},
+	{#State 76
+		ACTIONS => {
+			'IDENT' => 39,
+			'STRING' => 50
+		},
+		GOTOS => {
+			'symbol' => 81,
+			'ID' => 52,
+			'string_as_id' => 53
+		}
+	},
+	{#State 77
 		ACTIONS => {
 			'BRACED_CODE' => 82
 		},
 		GOTOS => {
-			'action' => 81
+			'action' => 83
 		}
 	},
-	{#State 74
-		DEFAULT => -58
-	},
-	{#State 75
-		ACTIONS => {
-			'IDENT' => 37,
-			'STRING' => 51
-		},
-		GOTOS => {
-			'symbol' => 83,
-			'string_as_id' => 50,
-			'ID' => 52
-		}
-	},
-	{#State 76
-		DEFAULT => -52
-	},
-	{#State 77
-		DEFAULT => -45
-	},
 	{#State 78
-		DEFAULT => -63
+		DEFAULT => -58
 	},
 	{#State 79
-		DEFAULT => -35
+		DEFAULT => -63
 	},
 	{#State 80
 		ACTIONS => {
-			'PERCENT_PREC' => 75,
+			'STRING' => 50,
 			'BRACED_CODE' => -57,
-			'IDENT' => 37,
-			'STRING' => 51,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 74
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 78,
+			'IDENT' => 39,
+			'PERCENT_PREC' => 76
 		},
 		DEFAULT => -50,
 		GOTOS => {
-			'ID' => 52,
-			'action_opt' => 73,
-			'symbol' => 76,
-			'string_as_id' => 50
+			'symbol' => 75,
+			'string_as_id' => 53,
+			'action_opt' => 77,
+			'ID' => 52
 		}
 	},
 	{#State 81
-		DEFAULT => -53
+		DEFAULT => -54
 	},
 	{#State 82
 		DEFAULT => -59
 	},
 	{#State 83
-		DEFAULT => -54
+		DEFAULT => -53
 	}
 ],
                                   yyrules  =>
