@@ -63,12 +63,12 @@ sub new {
 	},
 	{#State 2
 		ACTIONS => {
-			"%%" => 8,
-			'OPTION_OP' => 7,
-			'PROLOGUE' => 4
+			'PROLOGUE' => 7,
+			"%%" => 5,
+			'OPTION_OP' => 4
 		},
 		GOTOS => {
-			'options' => 5,
+			'options' => 8,
 			'declaration' => 6
 		}
 	},
@@ -76,175 +76,175 @@ sub new {
 		DEFAULT => 0
 	},
 	{#State 4
-		DEFAULT => -5
-	},
-	{#State 5
-		DEFAULT => -4
-	},
-	{#State 6
-		DEFAULT => -2
-	},
-	{#State 7
 		DEFAULT => -8,
 		GOTOS => {
 			'optionlist' => 9
 		}
 	},
-	{#State 8
+	{#State 5
 		ACTIONS => {
-			"[" => 15,
-			"(" => 22,
-			'EOF_OP' => 20,
-			'CHAR' => 19,
-			'NUMBER' => 17,
-			'STRING' => 10
+			'NUMBER' => 11,
+			"(" => 19,
+			"[" => 10,
+			'EOF_OP' => 14,
+			'CHAR' => 20,
+			'STRING' => 12
 		},
 		GOTOS => {
-			'value' => 21,
-			'equivalence_alternation' => 14,
-			'simple_alternation' => 13,
-			'pattern' => 12,
-			'rule' => 11,
-			'rules' => 18,
-			'equivalence_generator' => 16
+			'pattern' => 18,
+			'value' => 17,
+			'rule' => 16,
+			'simple_alternation' => 22,
+			'equivalence_generator' => 15,
+			'rules' => 21,
+			'equivalence_alternation' => 13
 		}
 	},
+	{#State 6
+		DEFAULT => -2
+	},
+	{#State 7
+		DEFAULT => -5
+	},
+	{#State 8
+		DEFAULT => -4
+	},
 	{#State 9
 		ACTIONS => {
-			'OPT_PREFIX' => 24
+			'OPT_PREFIX' => 23
 		},
 		DEFAULT => -6,
 		GOTOS => {
-			'option' => 23
+			'option' => 24
 		}
 	},
 	{#State 10
-		DEFAULT => -24
-	},
-	{#State 11
-		DEFAULT => -11
-	},
-	{#State 12
 		ACTIONS => {
-			"{" => 26,
-			'RETURN' => 25
-		}
-	},
-	{#State 13
-		DEFAULT => -16
-	},
-	{#State 14
-		DEFAULT => -17
-	},
-	{#State 15
-		ACTIONS => {
-			'STRING' => 10,
-			'CHAR' => 19,
-			'NUMBER' => 17,
-			'GENERATOR_STRING' => 28
+			'CHAR' => 20,
+			'STRING' => 12,
+			'GENERATOR_STRING' => 26,
+			'NUMBER' => 11
 		},
 		GOTOS => {
-			'value' => 27,
-			'alternation' => 29
+			'alternation' => 27,
+			'value' => 25
 		}
 	},
-	{#State 16
+	{#State 11
+		DEFAULT => -26
+	},
+	{#State 12
+		DEFAULT => -24
+	},
+	{#State 13
+		DEFAULT => -17
+	},
+	{#State 14
+		DEFAULT => -14
+	},
+	{#State 15
 		DEFAULT => -18
 	},
+	{#State 16
+		DEFAULT => -11
+	},
 	{#State 17
-		DEFAULT => -26
+		DEFAULT => -15
 	},
 	{#State 18
 		ACTIONS => {
-			'STRING' => 10,
-			"%%" => 32,
-			'EOF_OP' => 20,
-			'CHAR' => 19,
-			'NUMBER' => 17,
-			"[" => 15,
-			"(" => 22
-		},
-		DEFAULT => -27,
-		GOTOS => {
-			'equivalence_generator' => 16,
-			'rule' => 30,
-			'pattern' => 12,
-			'simple_alternation' => 13,
-			'equivalence_alternation' => 14,
-			'value' => 21,
-			'epilogue_opt' => 31
+			'RETURN' => 29,
+			"{" => 28
 		}
 	},
 	{#State 19
-		DEFAULT => -25
-	},
-	{#State 20
-		DEFAULT => -14
-	},
-	{#State 21
-		DEFAULT => -15
-	},
-	{#State 22
 		ACTIONS => {
-			'STRING' => 10,
-			'CHAR' => 19,
-			'NUMBER' => 17
+			'CHAR' => 20,
+			'STRING' => 12,
+			'NUMBER' => 11
 		},
 		GOTOS => {
-			'value' => 27,
-			'alternation' => 33
+			'alternation' => 30,
+			'value' => 25
 		}
 	},
-	{#State 23
-		DEFAULT => -7
+	{#State 20
+		DEFAULT => -25
 	},
-	{#State 24
+	{#State 21
+		ACTIONS => {
+			'CHAR' => 20,
+			"(" => 19,
+			'STRING' => 12,
+			'EOF_OP' => 14,
+			"%%" => 32,
+			"[" => 10,
+			'NUMBER' => 11
+		},
+		DEFAULT => -27,
+		GOTOS => {
+			'pattern' => 18,
+			'epilogue_opt' => 33,
+			'equivalence_alternation' => 13,
+			'rule' => 31,
+			'simple_alternation' => 22,
+			'equivalence_generator' => 15,
+			'value' => 17
+		}
+	},
+	{#State 22
+		DEFAULT => -16
+	},
+	{#State 23
 		ACTIONS => {
 			"=" => 34
 		}
 	},
+	{#State 24
+		DEFAULT => -7
+	},
 	{#State 25
 		ACTIONS => {
-			'IDENTIFIER' => 35
+			"|" => 35
 		}
 	},
 	{#State 26
 		ACTIONS => {
-			'RETURN' => 36
+			"]" => 36
 		}
 	},
 	{#State 27
 		ACTIONS => {
-			"|" => 37
+			"|" => 38,
+			"]" => 37
 		}
 	},
 	{#State 28
 		ACTIONS => {
-			"]" => 38
+			'RETURN' => 39
 		}
 	},
 	{#State 29
 		ACTIONS => {
-			"|" => 40,
-			"]" => 39
+			'IDENTIFIER' => 40
 		}
 	},
 	{#State 30
-		DEFAULT => -10
+		ACTIONS => {
+			"|" => 38,
+			")" => 41
+		}
 	},
 	{#State 31
-		DEFAULT => -1
+		DEFAULT => -10
 	},
 	{#State 32
 		ACTIONS => {
-			'EPILOGUE' => 41
+			'EPILOGUE' => 42
 		}
 	},
 	{#State 33
-		ACTIONS => {
-			")" => 42,
-			"|" => 40
-		}
+		DEFAULT => -1
 	},
 	{#State 34
 		ACTIONS => {
@@ -253,62 +253,62 @@ sub new {
 	},
 	{#State 35
 		ACTIONS => {
-			";" => 44
+			'NUMBER' => 11,
+			'STRING' => 12,
+			'CHAR' => 20
+		},
+		GOTOS => {
+			'value' => 44
 		}
 	},
 	{#State 36
-		ACTIONS => {
-			'IDENTIFIER' => 45
-		}
-	},
-	{#State 37
-		ACTIONS => {
-			'STRING' => 10,
-			'NUMBER' => 17,
-			'CHAR' => 19
-		},
-		GOTOS => {
-			'value' => 46
-		}
-	},
-	{#State 38
 		DEFAULT => -23
 	},
-	{#State 39
+	{#State 37
 		DEFAULT => -22
 	},
+	{#State 38
+		ACTIONS => {
+			'NUMBER' => 11,
+			'STRING' => 12,
+			'CHAR' => 20
+		},
+		GOTOS => {
+			'value' => 45
+		}
+	},
+	{#State 39
+		ACTIONS => {
+			'IDENTIFIER' => 46
+		}
+	},
 	{#State 40
 		ACTIONS => {
-			'STRING' => 10,
-			'CHAR' => 19,
-			'NUMBER' => 17
-		},
-		GOTOS => {
-			'value' => 47
+			";" => 47
 		}
 	},
 	{#State 41
-		DEFAULT => -28
+		DEFAULT => -21
 	},
 	{#State 42
-		DEFAULT => -21
+		DEFAULT => -28
 	},
 	{#State 43
 		DEFAULT => -9
 	},
 	{#State 44
-		DEFAULT => -13
+		DEFAULT => -19
 	},
 	{#State 45
+		DEFAULT => -20
+	},
+	{#State 46
 		ACTIONS => {
 			";" => 48
 		}
 	},
-	{#State 46
-		DEFAULT => -19
-	},
 	{#State 47
-		DEFAULT => -20
+		DEFAULT => -13
 	},
 	{#State 48
 		ACTIONS => {
